<?php

namespace App\Services\marketing;


use App\Exception\custom\MarketingException;
use App\Models\marketing\mysql\Marketing;
use App\Models\marketing\mysql\PindanActivityColonelConfig;

class PindanActivityColonelConfigService
{
    /**
     * 编辑团长分销活动配置
     * @param array $params
     * @return bool
     * @throws MarketingException
     */
    public static function editColonelConfig($params = [])
    {
        $date = $params["date"];
        $type = empty($params["type"]) ? PindanActivityColonelConfig::TYPE_COLONEL : $params["type"];
        $configList = json_decode($params["config"], true);

        if (empty($configList)) {
            throw new MarketingException(['cus' => MarketingException::COLONEL_CONFIG_NULL]);
        }

        if (count($configList) > 6) {
            throw new MarketingException(['cus' => MarketingException::COLONEL_LEVEL_SIX]);
        }
        PindanActivityColonelConfig::beginTransaction();

        $idsRes = PindanActivityColonelConfig::select(["colonel_config_id"], ["date" => $date, "type" => $type], []);
        if (!empty($idsRes)) {
            $ids = array_column($idsRes, "colonel_config_id");
            PindanActivityColonelConfig::deleteRecord(["colonel_config_id" => $ids]);
        }

        $data = [];
        foreach ($configList as $key => $item) {
            $data[$key]["date"] = $date;
            $data[$key]["level"] = $item["level"];
            $data[$key]["assess_order_num"] = $item["assess_order_num"];
            $data[$key]["reward_amount"] = $item["reward_amount"];
        }
        PindanActivityColonelConfig::save($data);

        if (!PindanActivityColonelConfig::commit()) {
            PindanActivityColonelConfig::rollback();
            throw new MarketingException(["cus" => 5]);
        }

        return true;
    }

    /**
     * 团长分销活动配置
     * @param array $params
     * @return array
     */
    public static function colonelConfig($params = [])
    {
        $day = empty($params["date"]) ? date("Y-m-d") : $params["date"];
        $type = empty($params["type"]) ? PindanActivityColonelConfig::TYPE_COLONEL : $params["type"];
        $list = PindanActivityColonelConfig::select("*", ["date" => $day, "type" => $type], []);

        $data = [];
        if (!empty($list)) {
            foreach ($list as $key => $item) {
                $data[$key]["colonel_config_id"] = $item["colonel_config_id"];
                $data[$key]["date"] = $item["date"];
                $data[$key]["level"] = $item["level"];
                $data[$key]["assess_order_num"] = $item["assess_order_num"];
                $data[$key]["reward_amount"] = $item["reward_amount"];
            }
            $sortKeys = array_column($data, "level");
            array_multisort($sortKeys, SORT_ASC, $data);
        }
        return $data;
    }

}